==> nextcloud-app-mail-1.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_CN.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
    "Updating account failed: " : "更新账号失败：",
    "Creating account failed: " : "创建账号失败：",
    "Embedded message %s" : "嵌入式消息 %s",
    "Important mail" : "重要邮件",
    "Mails" : "邮件",
    "Mail" : "邮件",
    "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
    "Defaults" : "默认",
    "Here you can select where Nextcloud Mail stores your drafts as well as sent and deleted messages." : "在这里，您可以选择 Nextcloud 邮件保存您的草稿以及已发送和删除的邮件的位置。",
    "Draft messages are saved to:" : "草稿邮件保存在：",
    "Sent messages are saved to:" : "已发送邮件保存在：",
    "Deleted messages are moved to:" : "已删除邮件将被移至：",
    "Auto" : "自动",
    "Name" : "姓名",
    "Mail Address" : "邮箱",
    "Password" : "密码",
    "Manual" : "手动",
    "IMAP Settings" : "IMAP 设置",
    "IMAP Host" : "IMAP 主机",
    "IMAP Security" : "IMAP 安全",
    "None" : "无",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Settings" : "SMTP 设置",
    "SMTP Host" : "SMTP 主机",
    "SMTP Security" : "SMTP 安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Connect" : "连接",
    "Add alias" : "添加别名",
    "Add mail account" : "添加邮件账号",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
    "Register as application for mail links" : "注册为邮件链接应用",
    "Show keyboard shortcuts" : "显示键盘快捷方式",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允许该应用收集有关您的互动的数据。 根据这些数据，该应用程序将适应您的偏好。 数据将仅存储在本地。",
    "From" : "发件人",
    "Select account" : "选择账号",
    "To" : "收件人",
    "Contact or email address …" : "联系人或邮箱地址...",
    "+ Cc/Bcc" : "+ 抄送/密送",
    "Cc" : "抄送",
    "No contacts found." : "未找到联系人。",
    "Bcc" : "密送",
    "Subject" : "主题",
    "Subject …" : "标题...",
    "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
    "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
    "Write message …" : "编写消息...",
    "Can not save draft because this account does not have a drafts mailbox configured." : "无法保存草稿，因为该账号没有配置草稿邮箱。",
    "Saving draft …" : "正在保存草稿 …",
    "Draft saved" : "草稿已保存",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Add attachment link from Files" : "从文件添加附件链接",
    "Enable formatting" : "启用格式化",
    "Encrypt message with Mailvelope" : "使用 Mailvelope 加密邮件",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
    "Uploading attachments …" : "正在上传附件…",
    "Sending …" : "正在发送…",
    "Error sending your message" : "发送您的消息时出错",
    "Go back" : "后退",
    "Retry" : "重试",
    "Message sent!" : "消息已发送！",
    "Write another message" : "再写一条消息",
    "Send" : "发送",
    "Encrypt and send" : "加密并发送",
    "Send unencrypted" : "不加密发送",
    "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
    "Uploading {percent}% …" : "正在上传 {percent}% …",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "Choose a file to share as a link" : "选择要共享的文件作为链接",
    "Writing mode" : "编写模式",
    "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
    "Plain text" : "纯文本",
    "Rich text" : "富文本",
    "No messages in this folder" : "该文件夹内没有消息",
    "No messages" : "没有消息",
    "Draft: " : "草稿: ",
    "Mark unimportant" : "标记为不重要",
    "Mark important" : "标记为重要",
    "Mark unfavorite" : "取消收藏",
    "Mark favorite" : "收藏",
    "Mark unread" : "标记为未读",
    "Mark read" : "标记为已读",
    "Mark not spam" : "标记为非垃圾邮件",
    "Mark as spam" : "标记为垃圾邮件",
    "Unselect" : "取消选择",
    "Select" : "选择",
    "Move" : "移动",
    "Edit as new message" : "编辑为新消息",
    "Delete" : "删除",
    "Blind copy recipients only" : "仅向收件人发送无信头副本",
    "No trash mailbox configured" : "没有配置垃圾邮箱",
    "Could not delete message" : "无法删除消息",
    "Mark {number} unread" : "将 {number} 标记为未读",
    "Mark {number} read" : "将 {number} 标记为已读",
    "Unfavorite {number}" : "取消收藏 {number}",
    "Favorite {number}" : "收藏 {number}",
    "Unselect {number}" : "取消选择 {number}",
    "Move {number}" : "移动 {number}",
    "Delete {number}" : "删除 {number}",
    "Load more" : "加载更多",
    "Report this bug" : "报告此问题",
    "Could not open mailbox" : "无法打开邮箱",
    "Loading messages" : "正在加载消息",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
    "Choose target folder" : "选择目标文件夹",
    "No more subfolders in here" : "没有更多的子文件夹",
    "Choose" : "选择",
    "Important" : "重要",
    "Important info" : "重要信息",
    "Favorites" : "收藏",
    "Other" : "其他",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "根据您与哪些消息互动或手动标记重要消息，消息会自动被标记为重要。在开始的时候，您可能需要手动改变重要性来调教系统，但随着时间的推移，它会不断改进。",
    "Attachments" : "附件",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”",
    "Unnamed" : "未命名",
    "Embedded message" : "嵌入式消息",
    "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
    "Save all to Files" : "全部保存到文件",
    "Choose a folder to store the attachments in" : "选择附件保存的目录",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此消息已使用 PGP 加密。 安装 Mailvelope 对其进行解密。",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images from this sender" : "显示此发件人的图片",
    "Message frame" : "消息框",
    "Quoted text" : "引用文字",
    "Moving" : "移动",
    "New message" : "新建消息",
    "Settings" : "设置",
    "Quota" : "配额",
    "Account settings" : "账号设置",
    "Show only subscribed folders" : "仅显示已订阅的文件夹",
    "Add folder" : "添加文件夹",
    "Saving" : "正在保存",
    "Move up" : "上移",
    "Move down" : "下移",
    "Remove account" : "移除账号",
    "Loading …" : "正在加载...",
    "Not supported by the server" : "服务器不支持",
    "{usage} of {limit} used" : "已使用{usage} / {limit}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 的账号和缓存的电子邮件数据将从 Nextcloud 中删除，但不会从您的电子邮件提供商那里删除。",
    "Remove account {email}" : "移除账号 {email}",
    "Remove {email}" : "移除 {email}",
    "Cancel" : "取消",
    "Show all subscribed folders" : "显示所有订阅的文件夹",
    "Show all folders" : "显示全部文件夹",
    "Collapse folders" : "折叠文件夹",
    "Mark all as read" : "标记所有为已读",
    "Mark all messages of this mailbox as read" : "将此邮箱中的所有消息都标记为已读",
    "Add subfolder" : "添加子文件夹",
    "Edit name" : "编辑名称",
    "Clear cache" : "清空缓存",
    "Clear locally cached data, in case there are issues with synchronization." : "万一同步出现问题，请清除本地缓存的数据。",
    "Subscribed" : "已订阅",
    "Sync in background" : "后台同步",
    "Delete folder" : "删除文件夹",
    "The folder and all messages in it will be deleted." : "该文件夹及其中的所有消息将被删除。",
    "Delete folder {name}" : "删除 {name} 文件夹",
    "An error occurred, unable to rename the mailbox." : "发生错误，无法重命名邮箱。",
    "_{total} message_::_{total} messages_" : ["{total} 条消息"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["总共 {total} 封邮件，{unread} 封未读邮件"],
    "Not found" : "没有找到",
    "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
    "Could not load your draft" : "无法加载您的草稿",
    "Could not load original message" : "无法加载初始消息",
    "No message selected" : "没有选择消息",
    "Signature" : "签名",
    "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
    "Signature …" : "签名...",
    "Save signature" : "保存签名",
    "Could not load your message thread" : "无法加载您的消息线线程",
    "Reply" : "回复",
    "Reply to sender only" : "只回复发送者",
    "Forward" : "转发",
    "View source" : "查看来源",
    "Download thread data for debugging" : "下载线程数据以进行调试",
    "Message source" : "消息来源",
    "Import into {calendar}" : "导入到 {calendar}",
    "Event imported into {calendar}" : "事件导入到 {calendar}",
    "Could not create event" : "无法建立事件",
    "Airplane" : "飞机",
    "Reservation {id}" : "预订 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} 航班从 {depAirport} 飞往 {arrAirport}",
    "Train" : "火车",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 从 {depStation} 到 {arrStation}",
    "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
    "Mail app" : "邮件应用",
    "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "在这里你可以找到实例范围的设置。用户特定的设置在应用本身里（左下角）。",
    "Email: {email}" : "电子邮件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
    "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以为账号设置配置模板，所有用户都可以从中获取预配置的账号。",
    "Provision an account for every user" : "为每个用户设置一个账号",
    "General" : "常规",
    "Email address" : "Email 地址",
    "IMAP" : "IMAP",
    "User" : "用户",
    "Host" : "主机",
    "Port" : "端口",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
    "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
    "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
    "Change name" : "更改名称",
    "Mail server" : "邮件服务器",
    "No message found yet" : "暂无消息",
    "Set up an account" : "设置一个账号",
    "Keyboard shortcut" : "键盘快捷键",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Search" : "搜索",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账号",
    "Unexpected error during account creation" : "创建账号时发生意外错误",
    "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
    "All" : "全部",
    "Archive" : "归档",
    "Drafts" : "草稿",
    "Priority inbox" : "优先收件箱",
    "All inboxes" : "所有收件箱",
    "Inbox" : "收件箱",
    "Junk" : "垃圾邮件",
    "Sent" : "已发送",
    "Trash" : "废件箱",
    "Error while sharing file" : "共享文件时出错",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load your message" : "无法加载您的消息",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "Error loading message" : "载入消息时发生错误",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此网页，您可以返回到<a href=\"%s\">邮件</a>应用。",
    "Continue to %s" : "继续 %s"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-1.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_CN.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
    "Updating account failed: " : "更新账号失败：",
    "Creating account failed: " : "创建账号失败：",
    "Embedded message %s" : "嵌入式消息 %s",
    "Important mail" : "重要邮件",
    "Unread mail" : "未读邮件",
    "Mails" : "邮件",
    "Mail" : "邮件",
    "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
    "Drafts are saved in:" : "草稿邮件被保存于：",
    "Sent messages are saved in:" : "已发送邮件被保存于：",
    "Deleted messages are moved in:" : "已删除邮件被移动到：",
    "Auto" : "自动",
    "Name" : "姓名",
    "Mail Address" : "邮箱",
    "Password" : "密码",
    "Manual" : "手动",
    "IMAP Settings" : "IMAP 设置",
    "IMAP Host" : "IMAP 主机",
    "IMAP Security" : "IMAP 安全",
    "None" : "无",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Settings" : "SMTP 设置",
    "SMTP Host" : "SMTP 主机",
    "SMTP Security" : "SMTP 安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Connect" : "连接",
    "Account settings" : "账号设置",
    "Change name" : "更改名称",
    "Signature" : "签名",
    "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
    "Writing mode" : "编写模式",
    "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
    "Default folders" : "默认文件夹",
    "The folders to use for drafts, sent messages and deleted messages." : "用于草稿邮件、已发送邮件和已删除邮件的文件夹。",
    "Mail server" : "邮件服务器",
    "Add alias" : "添加别名",
    "Add mail account" : "添加邮件账号",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
    "Register as application for mail links" : "注册为邮件链接应用",
    "Show keyboard shortcuts" : "显示键盘快捷方式",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允许该应用收集有关您的互动的数据。 根据这些数据，该应用程序将适应您的偏好。 数据将仅存储在本地。",
    "From" : "发件人",
    "Select account" : "选择账号",
    "To" : "收件人",
    "Contact or email address …" : "联系人或邮箱地址...",
    "+ Cc/Bcc" : "+ 抄送/密送",
    "Cc" : "抄送",
    "No contacts found." : "未找到联系人。",
    "Bcc" : "密送",
    "Subject" : "主题",
    "Subject …" : "标题...",
    "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
    "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
    "Write message …" : "编写消息...",
    "Can not save draft because this account does not have a drafts mailbox configured." : "无法保存草稿，因为该账号没有配置草稿邮箱。",
    "Saving draft …" : "正在保存草稿 …",
    "Draft saved" : "草稿已保存",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Enable formatting" : "启用格式化",
    "Request a read receipt" : "请求已读回执",
    "Encrypt message with Mailvelope" : "使用 Mailvelope 加密邮件",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
    "Uploading attachments …" : "正在上传附件…",
    "Sending …" : "正在发送…",
    "Error sending your message" : "发送您的消息时出错",
    "Go back" : "后退",
    "Retry" : "重试",
    "Message sent!" : "消息已发送！",
    "Write another message" : "再写一条消息",
    "Add share link from {productName} Files" : "添加来自 {productName} 文件的共享链接",
    "Send" : "发送",
    "Encrypt and send" : "加密并发送",
    "Send unencrypted" : "不加密发送",
    "Message {id} could not be found" : "消息 {id} 未找到",
    "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
    "Uploading {percent}% …" : "正在上传 {percent}% …",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "Choose a file to share as a link" : "选择要共享的文件作为链接",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超出了允许的附件最大大小 {size}。请通过链接共享文件。"],
    "No message found yet" : "暂无消息",
    "Set up an account" : "设置一个账号",
    "Plain text" : "纯文本",
    "Rich text" : "富文本",
    "No messages in this mailbox" : "此邮箱中没有消息",
    "No messages" : "没有消息",
    "Draft: " : "草稿: ",
    "Mark unimportant" : "标记为不重要",
    "Mark important" : "标记为重要",
    "Mark unfavorite" : "取消收藏",
    "Mark favorite" : "收藏",
    "Mark unread" : "标记为未读",
    "Mark read" : "标记为已读",
    "Mark not spam" : "标记为非垃圾邮件",
    "Mark as spam" : "标记为垃圾邮件",
    "Unselect" : "取消选择",
    "Select" : "选择",
    "Move" : "移动",
    "Edit as new message" : "编辑为新消息",
    "Delete" : "删除",
    "Blind copy recipients only" : "仅向收件人发送无信头副本",
    "No trash mailbox configured" : "没有配置垃圾邮箱",
    "Could not delete message" : "无法删除消息",
    "Mark {number} unread" : "将 {number} 标记为未读",
    "Mark {number} read" : "将 {number} 标记为已读",
    "Unfavorite {number}" : "取消收藏 {number}",
    "Favorite {number}" : "收藏 {number}",
    "Unselect {number}" : "取消选择 {number}",
    "Move {number}" : "移动 {number}",
    "Forward {number} as attachment" : "转发 {number} 作为附件 ",
    "Delete {number}" : "删除 {number}",
    "Load more" : "加载更多",
    "Report this bug" : "报告此问题",
    "Could not open mailbox" : "无法打开邮箱",
    "Loading messages" : "正在加载消息",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
    "Choose target mailbox" : "选择目标邮箱",
    "No more submailboxes in here" : "这里已经没有更多子邮箱",
    "Choose" : "选择",
    "Important info" : "重要信息",
    "Favorites" : "收藏",
    "Other" : "其他",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "根据您与哪些消息互动或手动标记重要消息，消息会自动被标记为重要。在开始的时候，您可能需要手动改变重要性来调教系统，但随着时间的推移，它会不断改进。",
    "The sender of this message has asked to be notified when you read this message." : "此邮件的发送方请求在您阅读此邮件时得到通知。 ",
    "Notify the sender" : "通知发件人",
    "You sent a read confirmation to the sender of this message." : "您向此消息的发送方发送了一个已读确认。",
    "Could not send mdn" : "无法发送 mdn",
    "Attachments" : "附件",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”",
    "Unnamed" : "未命名",
    "Embedded message" : "嵌入式消息",
    "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
    "Save all to Files" : "全部保存到文件",
    "Choose a folder to store the attachments in" : "选择附件保存的目录",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此消息已使用 PGP 加密。 安装 Mailvelope 对其进行解密。",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images from this sender" : "显示此发件人的图片",
    "Message frame" : "消息框",
    "Quoted text" : "引用文字",
    "Moving" : "移动",
    "New message" : "新建消息",
    "Settings" : "设置",
    "Quota" : "配额",
    "Show only subscribed mailboxes" : "只显示已订阅的邮箱",
    "Add mailbox" : "添加邮箱",
    "Saving" : "正在保存",
    "Move up" : "上移",
    "Move down" : "下移",
    "Remove account" : "移除账号",
    "Loading …" : "正在加载...",
    "Not supported by the server" : "服务器不支持",
    "{usage} of {limit} used" : "已使用{usage} / {limit}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 的账号和缓存的电子邮件数据将从 Nextcloud 中删除，但不会从您的电子邮件提供商那里删除。",
    "Remove account {email}" : "移除账号 {email}",
    "Remove {email}" : "移除 {email}",
    "Cancel" : "取消",
    "Show all subscribed mailbox" : "显示所有订阅的邮箱",
    "Show all mailboxes" : "显示所有邮箱",
    "Collapse mailboxes" : "折叠邮箱",
    "Mark all as read" : "标记所有为已读",
    "Mark all messages of this mailbox as read" : "将此邮箱中的所有消息都标记为已读",
    "Add submailbox" : "添加子邮箱",
    "Edit name" : "编辑名称",
    "Clear cache" : "清空缓存",
    "Clear locally cached data, in case there are issues with synchronization." : "万一同步出现问题，请清除本地缓存的数据。",
    "Subscribed" : "已订阅",
    "Sync in background" : "后台同步",
    "Delete mailbox" : "删除邮箱",
    "The mailbox and all messages in it will be deleted." : "邮箱和其中的所有邮件都将被删除。",
    "Delete mailbox {name}" : "删除邮箱 {name}",
    "An error occurred, unable to rename the mailbox." : "发生错误，无法重命名邮箱。",
    "_{total} message_::_{total} messages_" : ["{total} 条消息"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["总共 {total} 封邮件，{unread} 封未读邮件"],
    "Not found" : "没有找到",
    "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
    "Could not load your draft" : "无法加载您的草稿",
    "Could not load original message" : "无法加载初始消息",
    "No message selected" : "没有选择消息",
    "Signature …" : "签名...",
    "Save signature" : "保存签名",
    "Could not load your message thread" : "无法加载您的消息线线程",
    "Reply" : "回复",
    "Reply to sender only" : "只回复发送者",
    "Forward" : "转发",
    "View source" : "查看来源",
    "Download thread data for debugging" : "下载线程数据以进行调试",
    "Message source" : "消息来源",
    "Import into {calendar}" : "导入到 {calendar}",
    "Event imported into {calendar}" : "事件导入到 {calendar}",
    "Could not create event" : "无法建立事件",
    "Airplane" : "飞机",
    "Reservation {id}" : "预订 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} 航班从 {depAirport} 飞往 {arrAirport}",
    "Train" : "火车",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 从 {depStation} 到 {arrStation}",
    "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
    "Mail app" : "邮件应用",
    "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "在这里你可以找到实例范围的设置。用户特定的设置在应用本身里（左下角）。",
    "Email: {email}" : "电子邮件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
    "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以为账号设置配置模板，所有用户都可以从中获取预配置的账号。",
    "Provision an account for every user" : "为每个用户设置一个账号",
    "General" : "常规",
    "Email address" : "Email 地址",
    "IMAP" : "IMAP",
    "User" : "用户",
    "Host" : "主机",
    "Port" : "端口",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
    "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
    "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
    "Keyboard shortcut" : "键盘快捷键",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Search" : "搜索",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账号",
    "Unexpected error during account creation" : "创建账号时发生意外错误",
    "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
    "All" : "全部",
    "Archive" : "归档",
    "Drafts" : "草稿",
    "Priority inbox" : "优先收件箱",
    "All inboxes" : "所有收件箱",
    "Inbox" : "收件箱",
    "Junk" : "垃圾邮件",
    "Sent" : "已发送",
    "Trash" : "废件箱",
    "Error while sharing file" : "共享文件时出错",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load your message" : "无法加载您的消息",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "Error loading message" : "载入消息时发生错误",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此网页，您可以返回到<a href=\"%s\">邮件</a>应用。",
    "Continue to %s" : "继续 %s"
},
"nplurals=1; plural=0;");
